==> react-native-header-view-0.2.1.tgz: package/lib/components/Header.js <==
import React from "react";
import PropTypes from "prop-types";
import { Dimensions, View, Text, TouchableOpacity } from "react-native";
import Icon from "react-native-dynamic-vector-icons";
// Styles
import _styles, {
  container,
  _shadowStyle,
  hitSlop,
  ifIPhoneXHeader
} from "./Header.style";
import colors from "./colors.style";

const { width } = Dimensions.get("window");

const Header = props => {
  const {
    styles,
    hitSlops,
    shadowStyle,
    headerTitle,
    leftComponent,
    leftComponentStyle,
    leftComponentDisable,
    leftComponentOnPress,
    rightComponent,
    rightComponentStyle,
    rightComponentDisable,
    rightComponentOnPress,
    centerComponent,
    centerComponentStyle
  } = props;

  return (
    <View
      style={[
        styles || container(props),
        ifIPhoneXHeader,
        shadowStyle || _shadowStyle
      ]}
    >
      <View style={[_styles.innerContainer]}>
        {leftComponent || (
          <TouchableOpacity
            style={[
              leftComponentStyle || _styles.leftComponentStyle,
              {
                opacity: leftComponentDisable ? 0 : 1
              }
            ]}
            hitSlop={hitSlops || hitSlop}
            onPress={leftComponentOnPress}
          >
            <Icon
              name="ios-arrow-back"
              type="Ionicons"
              size={30}
              color={colors.theme.light.primary}
            />
          </TouchableOpacity>
        )}
        {centerComponent || (
          <Text style={[centerComponentStyle || _styles.centerComponentStyle]}>
            {headerTitle}
          </Text>
        )}
        {rightComponent || (
          <TouchableOpacity
            style={[
              rightComponentStyle || _styles.rightComponentStyle,
              {
                opacity: rightComponentDisable ? 0 : 1
              }
            ]}
            hitSlop={hitSlops || hitSlop}
            onPress={rightComponentOnPress}
          >
            <Icon
              name="ios-menu"
              type="ionicon"
              size={30}
              color={colors.theme.light.primaryWhite}
            />
          </TouchableOpacity>
        )}
      </View>
    </View>
  );
};

Header.propTypes = {
  styles: PropTypes.object,
  width: PropTypes.number,
  hitSlops: PropTypes.object,
  bottomStick: PropTypes.bool,
  shadowStyle: PropTypes.object,
  headerTitle: PropTypes.string,
  backgroundColor: PropTypes.string,
  leftComponent: PropTypes.element,
  leftComponentStyle: PropTypes.object,
  leftComponentDisable: PropTypes.bool,
  leftComponentOnPress: PropTypes.func,
  rightComponent: PropTypes.element,
  rightComponentStyle: PropTypes.object,
  rightComponentDisable: PropTypes.bool,
  rightComponentOnPress: PropTypes.func,
  centerComponent: PropTypes.element,
  centerComponentStyle: PropTypes.object
};

Header.defaultProps = {
  styles: null,
  width: width,
  hitSlops: hitSlop,
  bottomStick: false,
  shadowStyle: _shadowStyle,
  headerTitle: "",
  backgroundColor: "#fff",
  leftComponent: null,
  leftComponentStyle: null,
  leftComponentDisable: true,
  leftComponentOnPress: () => {},
  rightComponent: null,
  rightComponentStyle: null,
  rightComponentDisable: true,
  rightComponentOnPress: () => {},
  centerComponent: null,
  centerComponentStyle: null
};

export default Header;

==> react-native-header-view-0.2.2.tgz: package/lib/components/Header.js <==
import React from "react";
import { View, Text, TouchableOpacity } from "react-native";
import Icon from "react-native-dynamic-vector-icons";
import { ifIPhoneXHeader } from "./shared.style";
// Styles
import _styles, {
  container,
  _shadowStyle,
  innerContainer,
  _leftComponentStyle,
  _rightComponentStyle
} from "./Header.style";
import colors from "./colors.style";
const hitSlop = {
  top: 30,
  bottom: 30,
  left: 30,
  right: 30
};

const Header = props => {
  const {
    styles,
    hitSlops,
    shadowStyle,
    headerTitle,
    shadowColor,
    leftComponent,
    rightComponent,
    centerComponent,
    statusBarHidden,
    leftComponentStyle,
    rightComponentStyle,
    leftComponentDisable,
    leftComponentOnPress,
    centerComponentStyle,
    rightComponentDisable,
    rightComponentOnPress
  } = props;
  return (
    <View
      style={[
        styles || container(props),
        ifIPhoneXHeader,
        shadowStyle || _shadowStyle(shadowColor)
      ]}
    >
      <View style={[innerContainer(statusBarHidden)]}>
        {leftComponent || (
          <TouchableOpacity
            style={
              leftComponentStyle || _leftComponentStyle(leftComponentDisable)
            }
            hitSlop={hitSlops || hitSlop}
            onPress={leftComponentOnPress}
          >
            <Icon
              name="ios-arrow-back"
              type="Ionicons"
              size={30}
              color={colors.theme.light.primary}
            />
          </TouchableOpacity>
        )}
        {centerComponent || (
          <Text style={[centerComponentStyle || _styles.centerComponentStyle]}>
            {headerTitle}
          </Text>
        )}
        {rightComponent || (
          <TouchableOpacity
            style={
              rightComponentStyle || _rightComponentStyle(rightComponentDisable)
            }
            hitSlop={hitSlops || hitSlop}
            onPress={rightComponentOnPress}
          >
            <Icon
              name="ios-menu"
              type="ionicon"
              size={30}
              color={colors.theme.light.primaryWhite}
            />
          </TouchableOpacity>
        )}
      </View>
    </View>
  );
};

export default Header;
